@@ -39,6 +39,7 @@
  *        boolean bUseWidePunc;
  *        boolean bUseFullWidthChar;
  *        boolean bUsePreedit;
+ *        boolean bUseTraditional;
  *        char* imList;
  *    } FcitxProfile;
  * @endcode
@@ -53,6 +54,7 @@
  * CONFIG_BINDING_REGISTER_WITH_FILTER_ARG("Profile", "IMName", imName, FilterIMName, instance)
  * CONFIG_BINDING_REGISTER("Profile", "WidePunc", bUseWidePunc)
  * CONFIG_BINDING_REGISTER("Profile", "PreeditStringInClientWindow", bUsePreedit)
+ * CONFIG_BINDING_REGISTER("Profile", "ChineseimeUseTraditional", bUseTraditional)
  * CONFIG_BINDING_REGISTER_WITH_FILTER_ARG("Profile", "EnabledIMList", imList, FilterIMList, instance)
  * CONFIG_BINDING_END()
  * @endcode
@@ -238,7 +240,6 @@ extern "C"
         FcitxConfigEnum configEnum; /**< if type is enum, the enum item info */
 
         UT_hash_handle hh; /**< hash handle */
-        char *shownInDeepin; /**< is shown in deepin controlcenter */
     };
 
     union _FcitxConfigConstrain {
@@ -267,7 +268,9 @@ extern "C"
         boolean advance;
         FcitxConfigConstrain constrain;
         char* longDesc;
-        void* padding[16];
+        boolean shownInDeepin; /**< is shown in deepin controlcenter */
+        char padding2[3];
+        void* padding[14];
     };
 
     /**
